/* hestonvanilla.C computes vanilla call option price with Heston's Modell 
   for stochastic volatility
   Copyright (C) 2001 Gunter Winkler (guwi17@gmx.de)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <iostream>
#include <cmath>
#include <complex>
#include <cstdlib>

#include "hestonanalytic.h"

using std::cout;
using std::endl;

int main(int argc, char* argv[])
{
// input parameter check has yet to be implemented
	if(argc<12){
	   std::cout << "usage: " << argv[0] << " rd rf rho kappa theta xi lambda spot strike v t\n";
	   exit(1);
	}
	heston_complex z = heston_complex(0,1);
	MARKETDATA	market;
	DOUBLE	spot,strike,v,t;

// 	market.rd     = log(1.052); 
// 	market.rf     = log(1.048); 	/* (logarithmic) domestic/foreign interest rates */
// 	market.rho    = -0.1; 
// 	market.kappa  = 2.5; 
// 	market.theta  = 0.06; 
// 	market.xi     = 0.5;	/* stochastic volatility parameters */
// 	market.lambda = 0.0; 	/* price of volatility risk */
	
// 	market.rd     = log(1.05); 
// 	market.rf     = log(1.03); 	/* (logarithmic) domestic/foreign interest rates */
// 	market.rho    = 0.1; 
// 	market.kappa  = 2; 
// 	market.theta  = 0.0025; 
// 	market.xi     = 0.1;	/* stochastic volatility parameters */
// 	market.lambda = 0.0; 	/* price of volatility risk */

// 	spot = 1.03 ;
// 	v = 0.012769;
// 	t = 0.5;

	market.rd=atof(argv[1]);
	market.rf=atof(argv[2]);
	market.rho=atof(argv[3]);
	market.kappa=atof(argv[4]);
	market.theta=atof(argv[5]);
	market.xi=atof(argv[6]);
	market.lambda=atof(argv[7]);

	spot=atof(argv[8]);
	strike=atof(argv[9]);
	v=atof(argv[10]);
	t=atof(argv[11]);

// 	spot   = 1.00 ;
// 	strike = 1.00 ;
// 	v = 0.05225;
// 	t = 0.25;

	std::cout.precision(10);
// 	std::cout         << market.rd;
// 	std::cout << ", " << market.rf;
// 	std::cout << ", " << market.rho;
// 	std::cout << ", " << market.kappa;
// 	std::cout << ", " << market.theta;
// 	std::cout << ", " << market.xi;
// 	std::cout << ", " << market.lambda;
// 
// 	std::cout << ", " << spot;
// 	std::cout << ", " << strike;
// 	std::cout << ", " << v;
// 	std::cout << ", " << t;
// 	std::cout << endl;
//	std::cout << "call: ";
	std::cout << Heston_Call(spot, v, t, strike, market) << endl;

	return 0;
};
